// -*- mode: C++ -*-

// AUTOGENERATED BY glean_parser.  DO NOT EDIT.

/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef mozilla_GleanJSMetricsLookup_h
#define mozilla_GleanJSMetricsLookup_h

#include "mozilla/PerfectHash.h"
#include "mozilla/Maybe.h"
#include "mozilla/glean/bindings/MetricTypes.h"
#include "mozilla/glean/fog_ffi_generated.h"

#define GLEAN_INDEX_BITS (32)
#define GLEAN_TYPE_BITS (5)
#define GLEAN_ID_BITS (27)
#define GLEAN_TYPE_ID(id) ((id) >> GLEAN_ID_BITS)
#define GLEAN_METRIC_ID(id) ((id) & ((1ULL << GLEAN_ID_BITS) - 1))
#define GLEAN_OFFSET(entry) (entry & ((1ULL << GLEAN_INDEX_BITS) - 1))

namespace mozilla::glean {

// The category lookup table's entry type
using category_entry_t = uint32_t;
// The metric lookup table's entry type
// This is a bitpacked type with 32 bits available to index into
// the string table, 5 bits available to signify the metric type,
// and the remaining 27 bits devoted to 2 "signal"
// bits to signify important characteristics (metric's a labeled metric's
// submetric, metric's been registered at runtime) and 25 bits
// for built-in metric ids.
// Gives room for 33554432 of each combination of
// characteristics (which hopefully will prove to be enough).
using metric_entry_t = uint64_t;

static_assert(GLEAN_INDEX_BITS + GLEAN_TYPE_BITS + GLEAN_ID_BITS == sizeof(metric_entry_t) * 8, "Index, Type, and ID bits need to fit into a metric_entry_t");
static_assert(GLEAN_TYPE_BITS + GLEAN_ID_BITS <= sizeof(uint32_t) * 8, "Metric Types and IDs need to fit into at most 32 bits");
static_assert(45 < UINT32_MAX, "Too many metric categories generated.");
static_assert(222 < 33554432, "Too many metrics generated. Need room for 2 signal bits.");
static_assert(19 < 32, "Too many different metric types.");

static already_AddRefed<nsISupports> NewMetricFromId(uint32_t id) {
  uint32_t typeId = GLEAN_TYPE_ID(id);
  uint32_t metricId = GLEAN_METRIC_ID(id);

  switch (typeId) {
    case 1: /* event */
    {
      return MakeAndAddRef<GleanEvent>(metricId);
    }
    case 2: /* string_list */
    {
      return MakeAndAddRef<GleanStringList>(metricId);
    }
    case 3: /* datetime */
    {
      return MakeAndAddRef<GleanDatetime>(metricId);
    }
    case 4: /* uuid */
    {
      return MakeAndAddRef<GleanUuid>(metricId);
    }
    case 5: /* boolean */
    {
      return MakeAndAddRef<GleanBoolean>(metricId);
    }
    case 6: /* quantity */
    {
      return MakeAndAddRef<GleanQuantity>(metricId);
    }
    case 7: /* string */
    {
      return MakeAndAddRef<GleanString>(metricId);
    }
    case 8: /* counter */
    {
      return MakeAndAddRef<GleanCounter>(metricId);
    }
    case 9: /* labeled_counter */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 9);
    }
    case 10: /* denominator */
    {
      return MakeAndAddRef<GleanDenominator>(metricId);
    }
    case 11: /* numerator */
    {
      return MakeAndAddRef<GleanNumerator>(metricId);
    }
    case 12: /* timing_distribution */
    {
      return MakeAndAddRef<GleanTimingDistribution>(metricId);
    }
    case 13: /* labeled_boolean */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 13);
    }
    case 14: /* timespan */
    {
      return MakeAndAddRef<GleanTimespan>(metricId);
    }
    case 15: /* memory_distribution */
    {
      return MakeAndAddRef<GleanMemoryDistribution>(metricId);
    }
    case 16: /* labeled_string */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 16);
    }
    case 17: /* custom_distribution */
    {
      return MakeAndAddRef<GleanCustomDistribution>(metricId);
    }
    case 18: /* rate */
    {
      return MakeAndAddRef<GleanRate>(metricId);
    }
    case 19: /* url */
    {
      return MakeAndAddRef<GleanUrl>(metricId);
    }
    default:
    MOZ_ASSERT_UNREACHABLE("Invalid type ID reached when trying to instantiate a new metric");
    return nullptr;
  }
}

/**
 * Create a submetric instance for a labeled metric of the provided type and id for the given label.
 * Assigns or retrieves an id for the submetric from the SDK.
 *
 * @param aParentTypeId - The type of the parent labeled metric identified as a number generated during codegen.
 *                        Only used to identify which X of LabeledX you are so that X can be created here.
 * @param aParentMetricId - The metric id for the parent labeled metric.
 * @param aLabel - The label for the submetric. Might not adhere to the SDK label format.
 * @param aSubmetricId - an outparam which is assigned the submetric's SDK-generated submetric id.
 *                       Used only by GIFFT.
 */
static already_AddRefed<nsISupports> NewSubMetricFromIds(uint32_t aParentTypeId, uint32_t aParentMetricId, const nsACString& aLabel, uint32_t* aSubmetricId) {
  switch (aParentTypeId) {
    case 9: { /* labeled_counter */
      auto id = impl::fog_labeled_counter_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanCounter>(id);
    }
    case 13: { /* labeled_boolean */
      auto id = impl::fog_labeled_boolean_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanBoolean>(id);
    }
    case 16: { /* labeled_string */
      auto id = impl::fog_labeled_string_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanString>(id);
    }
    default: {
      MOZ_ASSERT_UNREACHABLE("Invalid type ID for submetric.");
      return nullptr;
    }
  }
}

static Maybe<uint32_t> category_result_check(const nsACString& aKey, category_entry_t entry);
static Maybe<uint32_t> metric_result_check(const nsACString& aKey, metric_entry_t entry);

#if defined(_MSC_VER) && !defined(__clang__)
const char gCategoryStringTable[] = {
#else
constexpr char gCategoryStringTable[] = {
#endif
  /*     0 - "browserLaunchedToHandle" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'L', 'a', 'u', 'n', 'c', 'h', 'e', 'd', 'T', 'o', 'H', 'a', 'n', 'd', 'l', 'e', '\0',
  /*    24 - "backgroundUpdate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*    41 - "newtab" */ 'n', 'e', 'w', 't', 'a', 'b', '\0',
  /*    48 - "newtabSearch" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '\0',
  /*    61 - "topsites" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '\0',
  /*    70 - "pocket" */ 'p', 'o', 'c', 'k', 'e', 't', '\0',
  /*    77 - "newtabSearchAd" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '\0',
  /*    92 - "serp" */ 's', 'e', 'r', 'p', '\0',
  /*    97 - "urlbar" */ 'u', 'r', 'l', 'b', 'a', 'r', '\0',
  /*   104 - "browserEngagement" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*   122 - "pingCentre" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '\0',
  /*   133 - "gmp" */ 'g', 'm', 'p', '\0',
  /*   137 - "rtcrtpsender" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '\0',
  /*   150 - "rtcrtpsenderSetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*   176 - "perf" */ 'p', 'e', 'r', 'f', '\0',
  /*   181 - "paint" */ 'p', 'a', 'i', 'n', 't', '\0',
  /*   187 - "wr" */ 'w', 'r', '\0',
  /*   190 - "netwerk" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '\0',
  /*   198 - "network" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '\0',
  /*   206 - "backgroundTasksRmdirBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '\0',
  /*   231 - "backgroundTasksRmdirQuota" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '\0',
  /*   257 - "backgroundTasksRmdirHttpCache" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '\0',
  /*   287 - "cookieBanners" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '\0',
  /*   301 - "cookieBannersClick" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '\0',
  /*   320 - "crash" */ 'c', 'r', 'a', 's', 'h', '\0',
  /*   326 - "extensions" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\0',
  /*   337 - "fog" */ 'f', 'o', 'g', '\0',
  /*   341 - "fogIpc" */ 'f', 'o', 'g', 'I', 'p', 'c', '\0',
  /*   348 - "serverKnobs" */ 's', 'e', 'r', 'v', 'e', 'r', 'K', 'n', 'o', 'b', 's', '\0',
  /*   360 - "testOnly" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '\0',
  /*   369 - "testOnlyIpc" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '\0',
  /*   381 - "testOnlyJog" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '\0',
  /*   393 - "nimbusEvents" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '\0',
  /*   406 - "pdfjs" */ 'p', 'd', 'f', 'j', 's', '\0',
  /*   412 - "power" */ 'p', 'o', 'w', 'e', 'r', '\0',
  /*   418 - "powerWakeupsPerThread" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
  /*   440 - "powerCpuMsPerThread" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
  /*   460 - "powerBattery" */ 'p', 'o', 'w', 'e', 'r', 'B', 'a', 't', 't', 'e', 'r', 'y', '\0',
  /*   473 - "searchEngineDefault" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '\0',
  /*   493 - "searchEnginePrivate" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '\0',
  /*   513 - "dap" */ 'd', 'a', 'p', '\0',
  /*   517 - "legacyTelemetry" */ 'l', 'e', 'g', 'a', 'c', 'y', 'T', 'e', 'l', 'e', 'm', 'e', 't', 'r', 'y', '\0',
  /*   533 - "firstStartup" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '\0',
  /*   546 - "update" */ 'u', 'p', 'd', 'a', 't', 'e', '\0',
  /*   553 - "timerThread" */ 't', 'i', 'm', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
};


static_assert(sizeof(gCategoryStringTable) < UINT32_MAX, "Category string table is too large.");

const category_entry_t sCategoryByNameLookupEntries[] = {
  104ul,
  341ul,
  137ul,
  122ul,
  348ul,
  553ul,
  97ul,
  206ul,
  133ul,
  198ul,
  287ul,
  381ul,
  301ul,
  517ul,
  360ul,
  77ul,
  473ul,
  0ul,
  406ul,
  257ul,
  92ul,
  181ul,
  546ul,
  231ul,
  460ul,
  41ul,
  393ul,
  190ul,
  61ul,
  48ul,
  326ul,
  513ul,
  150ul,
  176ul,
  24ul,
  70ul,
  320ul,
  187ul,
  337ul,
  369ul,
  412ul,
  418ul,
  440ul,
  493ul,
  533ul
};



static Maybe<uint32_t>
CategoryByNameLookup(const nsACString& aKey)
{
  static const uint8_t BASES[] = {
       0,   0,   4,   0,   0,   1,   3,   1,   2,   0,   1,   1,   1,   2,   1,   1,
       3,   1,   1,   3,   1,   2,   6,   0,   1,   0,   2,   0,   0,   0,   7,   5,
       5,   0,   0,   2,   0,   0,   9,   9,   0,   0,   0,   0,   6,   0,   0,   2,
       0,  10,   0,   1,   7,   0,  20,   4,   0,   0,  16,   0,   5,   0,   0,   1,
  };
  

  const char* bytes = aKey.BeginReading();
  size_t length = aKey.Length();
  auto& entry = mozilla::perfecthash::Lookup(bytes, length, BASES,
                                             sCategoryByNameLookupEntries);
  return category_result_check(aKey, entry);
}


#if defined(_MSC_VER) && !defined(__clang__)
const char gMetricStringTable[] = {
#else
constexpr char gMetricStringTable[] = {
#endif
  /*     0 - "browserLaunchedToHandle.systemNotification" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'L', 'a', 'u', 'n', 'c', 'h', 'e', 'd', 'T', 'o', 'H', 'a', 'n', 'd', 'l', 'e', '.', 's', 'y', 's', 't', 'e', 'm', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\0',
  /*    43 - "backgroundUpdate.reasonsToNotUpdate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'a', 's', 'o', 'n', 's', 'T', 'o', 'N', 'o', 't', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*    79 - "backgroundUpdate.timeLastUpdateScheduled" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'i', 'm', 'e', 'L', 'a', 's', 't', 'U', 'p', 'd', 'a', 't', 'e', 'S', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'd', '\0',
  /*   120 - "backgroundUpdate.clientId" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', '\0',
  /*   146 - "backgroundUpdate.targetingExists" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'x', 'i', 's', 't', 's', '\0',
  /*   179 - "backgroundUpdate.targetingException" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\0',
  /*   215 - "backgroundUpdate.targetingVersion" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'V', 'e', 'r', 's', 'i', 'o', 'n', '\0',
  /*   249 - "backgroundUpdate.targetingEnvFirefoxVersion" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'F', 'i', 'r', 'e', 'f', 'o', 'x', 'V', 'e', 'r', 's', 'i', 'o', 'n', '\0',
  /*   293 - "backgroundUpdate.targetingEnvCurrentDate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'D', 'a', 't', 'e', '\0',
  /*   334 - "backgroundUpdate.targetingEnvProfileAge" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 'A', 'g', 'e', '\0',
  /*   374 - "backgroundUpdate.finalState" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'f', 'i', 'n', 'a', 'l', 'S', 't', 'a', 't', 'e', '\0',
  /*   402 - "backgroundUpdate.states" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 's', 't', 'a', 't', 'e', 's', '\0',
  /*   426 - "backgroundUpdate.reasons" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'a', 's', 'o', 'n', 's', '\0',
  /*   451 - "backgroundUpdate.exitCodeSuccess" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'e', 'x', 'i', 't', 'C', 'o', 'd', 'e', 'S', 'u', 'c', 'c', 'e', 's', 's', '\0',
  /*   484 - "backgroundUpdate.exitCodeException" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'e', 'x', 'i', 't', 'C', 'o', 'd', 'e', 'E', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\0',
  /*   519 - "newtab.locale" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'l', 'o', 'c', 'a', 'l', 'e', '\0',
  /*   533 - "newtab.newtabCategory" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'n', 'e', 'w', 't', 'a', 'b', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\0',
  /*   555 - "newtab.homepageCategory" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'h', 'o', 'm', 'e', 'p', 'a', 'g', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\0',
  /*   579 - "newtab.opened" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'o', 'p', 'e', 'n', 'e', 'd', '\0',
  /*   593 - "newtab.closed" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'c', 'l', 'o', 's', 'e', 'd', '\0',
  /*   607 - "newtabSearch.enabled" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   628 - "newtabSearch.issued" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '.', 'i', 's', 's', 'u', 'e', 'd', '\0',
  /*   648 - "topsites.enabled" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   665 - "topsites.sponsoredEnabled" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   691 - "topsites.impression" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   711 - "topsites.click" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*   726 - "pocket.isSignedIn" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'i', 's', 'S', 'i', 'g', 'n', 'e', 'd', 'I', 'n', '\0',
  /*   744 - "pocket.enabled" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   759 - "pocket.sponsoredStoriesEnabled" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 'S', 't', 'o', 'r', 'i', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*   790 - "pocket.impression" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   808 - "pocket.click" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*   821 - "pocket.save" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 's', 'a', 'v', 'e', '\0',
  /*   833 - "pocket.topicClick" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 't', 'o', 'p', 'i', 'c', 'C', 'l', 'i', 'c', 'k', '\0',
  /*   851 - "newtabSearchAd.impression" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   877 - "newtabSearchAd.click" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*   898 - "serp.impression" */ 's', 'e', 'r', 'p', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   914 - "serp.engagement" */ 's', 'e', 'r', 'p', '.', 'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*   930 - "urlbar.abandonment" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'a', 'b', 'a', 'n', 'd', 'o', 'n', 'm', 'e', 'n', 't', '\0',
  /*   949 - "urlbar.engagement" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*   967 - "urlbar.impression" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*   985 - "urlbar.prefMaxResults" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'M', 'a', 'x', 'R', 'e', 's', 'u', 'l', 't', 's', '\0',
  /*  1007 - "urlbar.prefSuggestTopsites" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'S', 'u', 'g', 'g', 'e', 's', 't', 'T', 'o', 'p', 's', 'i', 't', 'e', 's', '\0',
  /*  1034 - "browserEngagement.activeTicks" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'a', 'c', 't', 'i', 'v', 'e', 'T', 'i', 'c', 'k', 's', '\0',
  /*  1064 - "browserEngagement.uriCount" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'u', 'r', 'i', 'C', 'o', 'u', 'n', 't', '\0',
  /*  1091 - "pingCentre.sendFailures" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  1115 - "pingCentre.sendFailuresByNamespace" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', 'B', 'y', 'N', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', '\0',
  /*  1150 - "pingCentre.sendSuccessesByNamespace" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'S', 'u', 'c', 'c', 'e', 's', 's', 'e', 's', 'B', 'y', 'N', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', '\0',
  /*  1186 - "gmp.updateXmlFetchResult" */ 'g', 'm', 'p', '.', 'u', 'p', 'd', 'a', 't', 'e', 'X', 'm', 'l', 'F', 'e', 't', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', '\0',
  /*  1211 - "rtcrtpsender.count" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'c', 'o', 'u', 'n', 't', '\0',
  /*  1230 - "rtcrtpsender.countSetparametersCompat" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'c', 'o', 'u', 'n', 't', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 'C', 'o', 'm', 'p', 'a', 't', '\0',
  /*  1268 - "rtcrtpsender.usedSendencodings" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'u', 's', 'e', 'd', 'S', 'e', 'n', 'd', 'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 's', '\0',
  /*  1299 - "rtcrtpsenderSetparameters.warnNoGetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'N', 'o', 'G', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*  1345 - "rtcrtpsenderSetparameters.warnLengthChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'L', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1389 - "rtcrtpsenderSetparameters.warnRidChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'R', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1430 - "rtcrtpsenderSetparameters.warnNoTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'N', 'o', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1476 - "rtcrtpsenderSetparameters.warnStaleTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'S', 't', 'a', 'l', 'e', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1525 - "rtcrtpsenderSetparameters.failLengthChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'L', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1569 - "rtcrtpsenderSetparameters.failRidChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'R', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  1610 - "rtcrtpsenderSetparameters.failNoGetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'G', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*  1656 - "rtcrtpsenderSetparameters.failNoTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1702 - "rtcrtpsenderSetparameters.failStaleTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'S', 't', 'a', 'l', 'e', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  1751 - "rtcrtpsenderSetparameters.failNoEncodings" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 's', '\0',
  /*  1793 - "rtcrtpsenderSetparameters.failOther" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'O', 't', 'h', 'e', 'r', '\0',
  /*  1829 - "perf.pageLoad" */ 'p', 'e', 'r', 'f', '.', 'p', 'a', 'g', 'e', 'L', 'o', 'a', 'd', '\0',
  /*  1843 - "paint.buildDisplaylistTime" */ 'p', 'a', 'i', 'n', 't', '.', 'b', 'u', 'i', 'l', 'd', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'l', 'i', 's', 't', 'T', 'i', 'm', 'e', '\0',
  /*  1870 - "wr.gpuWaitTime" */ 'w', 'r', '.', 'g', 'p', 'u', 'W', 'a', 'i', 't', 'T', 'i', 'm', 'e', '\0',
  /*  1885 - "wr.rasterizeGlyphsTime" */ 'w', 'r', '.', 'r', 'a', 's', 't', 'e', 'r', 'i', 'z', 'e', 'G', 'l', 'y', 'p', 'h', 's', 'T', 'i', 'm', 'e', '\0',
  /*  1908 - "wr.rasterizeBlobsTime" */ 'w', 'r', '.', 'r', 'a', 's', 't', 'e', 'r', 'i', 'z', 'e', 'B', 'l', 'o', 'b', 's', 'T', 'i', 'm', 'e', '\0',
  /*  1930 - "wr.rendererTime" */ 'w', 'r', '.', 'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'T', 'i', 'm', 'e', '\0',
  /*  1946 - "wr.rendererTimeNoSc" */ 'w', 'r', '.', 'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'T', 'i', 'm', 'e', 'N', 'o', 'S', 'c', '\0',
  /*  1966 - "wr.framebuildTime" */ 'w', 'r', '.', 'f', 'r', 'a', 'm', 'e', 'b', 'u', 'i', 'l', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  1984 - "wr.scenebuildTime" */ 'w', 'r', '.', 's', 'c', 'e', 'n', 'e', 'b', 'u', 'i', 'l', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  2002 - "wr.sceneswapTime" */ 'w', 'r', '.', 's', 'c', 'e', 'n', 'e', 's', 'w', 'a', 'p', 'T', 'i', 'm', 'e', '\0',
  /*  2019 - "wr.textureCacheUpdateTime" */ 'w', 'r', '.', 't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'a', 'c', 'h', 'e', 'U', 'p', 'd', 'a', 't', 'e', 'T', 'i', 'm', 'e', '\0',
  /*  2045 - "wr.timeToFrameBuild" */ 'w', 'r', '.', 't', 'i', 'm', 'e', 'T', 'o', 'F', 'r', 'a', 'm', 'e', 'B', 'u', 'i', 'l', 'd', '\0',
  /*  2065 - "wr.timeToRenderStart" */ 'w', 'r', '.', 't', 'i', 'm', 'e', 'T', 'o', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 'r', 't', '\0',
  /*  2086 - "netwerk.earlyHints" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '.', 'e', 'a', 'r', 'l', 'y', 'H', 'i', 'n', 't', 's', '\0',
  /*  2105 - "netwerk.ehLinkType" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '.', 'e', 'h', 'L', 'i', 'n', 'k', 'T', 'y', 'p', 'e', '\0',
  /*  2124 - "network.dataSizePerType" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '.', 'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 'P', 'e', 'r', 'T', 'y', 'p', 'e', '\0',
  /*  2148 - "network.dataSizePbPerType" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '.', 'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 'P', 'b', 'P', 'e', 'r', 'T', 'y', 'p', 'e', '\0',
  /*  2174 - "backgroundTasksRmdirBase.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  2210 - "backgroundTasksRmdirBase.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  2245 - "backgroundTasksRmdirBase.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  2279 - "backgroundTasksRmdirBase.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2315 - "backgroundTasksRmdirBase.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2353 - "backgroundTasksRmdirBase.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  2388 - "backgroundTasksRmdirBase.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2432 - "backgroundTasksRmdirBase.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  2474 - "backgroundTasksRmdirQuota.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  2511 - "backgroundTasksRmdirQuota.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  2547 - "backgroundTasksRmdirQuota.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  2582 - "backgroundTasksRmdirQuota.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2619 - "backgroundTasksRmdirQuota.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2658 - "backgroundTasksRmdirQuota.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  2694 - "backgroundTasksRmdirQuota.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2739 - "backgroundTasksRmdirQuota.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  2782 - "backgroundTasksRmdirHttpCache.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  2823 - "backgroundTasksRmdirHttpCache.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  2863 - "backgroundTasksRmdirHttpCache.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  2902 - "backgroundTasksRmdirHttpCache.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2943 - "backgroundTasksRmdirHttpCache.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  2986 - "backgroundTasksRmdirHttpCache.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  3026 - "backgroundTasksRmdirHttpCache.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  3075 - "backgroundTasksRmdirHttpCache.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  3122 - "cookieBanners.normalWindowServiceMode" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'n', 'o', 'r', 'm', 'a', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', '\0',
  /*  3160 - "cookieBanners.privateWindowServiceMode" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'p', 'r', 'i', 'v', 'a', 't', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', '\0',
  /*  3199 - "cookieBanners.serviceDetectOnly" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'D', 'e', 't', 'e', 'c', 't', 'O', 'n', 'l', 'y', '\0',
  /*  3231 - "cookieBanners.ruleLookupByLoad" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'u', 'l', 'e', 'L', 'o', 'o', 'k', 'u', 'p', 'B', 'y', 'L', 'o', 'a', 'd', '\0',
  /*  3262 - "cookieBanners.ruleLookupByDomain" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'u', 'l', 'e', 'L', 'o', 'o', 'k', 'u', 'p', 'B', 'y', 'D', 'o', 'm', 'a', 'i', 'n', '\0',
  /*  3295 - "cookieBanners.reload" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'e', 'l', 'o', 'a', 'd', '\0',
  /*  3316 - "cookieBannersClick.handleDuration" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'h', 'a', 'n', 'd', 'l', 'e', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  3350 - "cookieBannersClick.result" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'r', 'e', 's', 'u', 'l', 't', '\0',
  /*  3376 - "crash.uptime" */ 'c', 'r', 'a', 's', 'h', '.', 'u', 'p', 't', 'i', 'm', 'e', '\0',
  /*  3389 - "crash.processType" */ 'c', 'r', 'a', 's', 'h', '.', 'p', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', '\0',
  /*  3407 - "crash.time" */ 'c', 'r', 'a', 's', 'h', '.', 't', 'i', 'm', 'e', '\0',
  /*  3418 - "crash.startup" */ 'c', 'r', 'a', 's', 'h', '.', 's', 't', 'a', 'r', 't', 'u', 'p', '\0',
  /*  3432 - "extensions.startupCacheLoadTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'L', 'o', 'a', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  3464 - "fog.initialization" */ 'f', 'o', 'g', '.', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', '\0',
  /*  3483 - "fog.failedIdleRegistration" */ 'f', 'o', 'g', '.', 'f', 'a', 'i', 'l', 'e', 'd', 'I', 'd', 'l', 'e', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  3510 - "fogIpc.replayFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'r', 'e', 'p', 'l', 'a', 'y', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  3532 - "fogIpc.bufferSizes" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'b', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 's', '\0',
  /*  3551 - "fogIpc.flushDurations" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'f', 'l', 'u', 's', 'h', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', '\0',
  /*  3573 - "fogIpc.flushFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'f', 'l', 'u', 's', 'h', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  3594 - "fogIpc.shutdownRegistrationFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 's', 'h', 'u', 't', 'd', 'o', 'w', 'n', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  3630 - "serverKnobs.validation" */ 's', 'e', 'r', 'v', 'e', 'r', 'K', 'n', 'o', 'b', 's', '.', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\0',
  /*  3653 - "testOnly.badCode" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'b', 'a', 'd', 'C', 'o', 'd', 'e', '\0',
  /*  3670 - "testOnly.canWeTimeIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'a', 'n', 'W', 'e', 'T', 'i', 'm', 'e', 'I', 't', '\0',
  /*  3691 - "testOnly.cheesyString" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'h', 'e', 'e', 's', 'y', 'S', 't', 'r', 'i', 'n', 'g', '\0',
  /*  3713 - "testOnly.cheesyStringList" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'h', 'e', 'e', 's', 'y', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', '\0',
  /*  3739 - "testOnly.whatADate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'A', 'D', 'a', 't', 'e', '\0',
  /*  3758 - "testOnly.whatIdIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'I', 'd', 'I', 't', '\0',
  /*  3776 - "testOnly.canWeFlagIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'a', 'n', 'W', 'e', 'F', 'l', 'a', 'g', 'I', 't', '\0',
  /*  3797 - "testOnly.doYouRemember" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'd', 'o', 'Y', 'o', 'u', 'R', 'e', 'm', 'e', 'm', 'b', 'e', 'r', '\0',
  /*  3820 - "testOnly.whatTimeIsIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'T', 'i', 'm', 'e', 'I', 's', 'I', 't', '\0',
  /*  3842 - "testOnly.mabelsKitchenCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'K', 'i', 't', 'c', 'h', 'e', 'n', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  3873 - "testOnly.mabelsBathroomCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 't', 'h', 'r', 'o', 'o', 'm', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  3905 - "testOnly.mabelsLikeBalloons" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'i', 'k', 'e', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 's', '\0',
  /*  3933 - "testOnly.mabelsBalloonStrings" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 'S', 't', 'r', 'i', 'n', 'g', 's', '\0',
  /*  3963 - "testOnly.mabelsLabelMaker" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'a', 'b', 'e', 'l', 'M', 'a', 'k', 'e', 'r', '\0',
  /*  3989 - "testOnly.mirrorTime" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 'T', 'i', 'm', 'e', '\0',
  /*  4009 - "testOnly.mirrorTimeNanos" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 'T', 'i', 'm', 'e', 'N', 'a', 'n', 'o', 's', '\0',
  /*  4034 - "testOnly.mirrorsForLabeledBools" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 's', 'F', 'o', 'r', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'B', 'o', 'o', 'l', 's', '\0',
  /*  4066 - "testOnly.onePingOneBool" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'o', 'n', 'e', 'P', 'i', 'n', 'g', 'O', 'n', 'e', 'B', 'o', 'o', 'l', '\0',
  /*  4090 - "testOnly.meaningOfLife" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'e', 'a', 'n', 'i', 'n', 'g', 'O', 'f', 'L', 'i', 'f', 'e', '\0',
  /*  4113 - "testOnlyIpc.aCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  4134 - "testOnlyIpc.aBool" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'B', 'o', 'o', 'l', '\0',
  /*  4152 - "testOnlyIpc.aDate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'D', 'a', 't', 'e', '\0',
  /*  4170 - "testOnlyIpc.aString" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'S', 't', 'r', 'i', 'n', 'g', '\0',
  /*  4190 - "testOnlyIpc.aMemoryDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'M', 'e', 'm', 'o', 'r', 'y', 'D', 'i', 's', 't', '\0',
  /*  4214 - "testOnlyIpc.aTimingDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'T', 'i', 'm', 'i', 'n', 'g', 'D', 'i', 's', 't', '\0',
  /*  4238 - "testOnlyIpc.aCustomDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'C', 'u', 's', 't', 'o', 'm', 'D', 'i', 's', 't', '\0',
  /*  4262 - "testOnlyIpc.aStringList" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', '\0',
  /*  4286 - "testOnlyIpc.anEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'E', 'v', 'e', 'n', 't', '\0',
  /*  4306 - "testOnlyIpc.eventWithExtra" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'e', 'v', 'e', 'n', 't', 'W', 'i', 't', 'h', 'E', 'x', 't', 'r', 'a', '\0',
  /*  4333 - "testOnlyIpc.noExtraEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'n', 'o', 'E', 'x', 't', 'r', 'a', 'E', 'v', 'e', 'n', 't', '\0',
  /*  4358 - "testOnlyIpc.aUuid" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'U', 'u', 'i', 'd', '\0',
  /*  4376 - "testOnlyIpc.aLabeledCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  4404 - "testOnlyIpc.anotherLabeledCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'o', 't', 'h', 'e', 'r', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  4438 - "testOnlyIpc.aQuantity" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'Q', 'u', 'a', 'n', 't', 'i', 't', 'y', '\0',
  /*  4460 - "testOnlyIpc.irate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'i', 'r', 'a', 't', 'e', '\0',
  /*  4478 - "testOnlyIpc.rateWithExternalDenominator" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'r', 'a', 't', 'e', 'W', 'i', 't', 'h', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\0',
  /*  4518 - "testOnlyIpc.anExternalDenominator" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\0',
  /*  4552 - "testOnlyIpc.aUrl" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'U', 'r', 'l', '\0',
  /*  4569 - "testOnlyJog.aCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '.', 'a', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  4590 - "testOnlyJog.anEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '.', 'a', 'n', 'E', 'v', 'e', 'n', 't', '\0',
  /*  4610 - "nimbusEvents.enrollment" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'n', 'r', 'o', 'l', 'l', 'm', 'e', 'n', 't', '\0',
  /*  4634 - "nimbusEvents.enrollFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'n', 'r', 'o', 'l', 'l', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  4660 - "nimbusEvents.unenrollment" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'u', 'n', 'e', 'n', 'r', 'o', 'l', 'l', 'm', 'e', 'n', 't', '\0',
  /*  4686 - "nimbusEvents.unenrollFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'u', 'n', 'e', 'n', 'r', 'o', 'l', 'l', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  4714 - "nimbusEvents.exposure" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\0',
  /*  4736 - "nimbusEvents.validationFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  4766 - "pdfjs.editing" */ 'p', 'd', 'f', 'j', 's', '.', 'e', 'd', 'i', 't', 'i', 'n', 'g', '\0',
  /*  4780 - "pdfjs.buttons" */ 'p', 'd', 'f', 'j', 's', '.', 'b', 'u', 't', 't', 'o', 'n', 's', '\0',
  /*  4794 - "pdfjs.used" */ 'p', 'd', 'f', 'j', 's', '.', 'u', 's', 'e', 'd', '\0',
  /*  4805 - "pdfjs.timeToView" */ 'p', 'd', 'f', 'j', 's', '.', 't', 'i', 'm', 'e', 'T', 'o', 'V', 'i', 'e', 'w', '\0',
  /*  4822 - "power.cpuTimeBogusValues" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'B', 'o', 'g', 'u', 's', 'V', 'a', 'l', 'u', 'e', 's', '\0',
  /*  4847 - "power.cpuTimePerProcessTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /*  4877 - "power.cpuTimePerTrackerTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'T', 'r', 'a', 'c', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /*  4907 - "power.gpuTimePerProcessTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'g', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /*  4937 - "power.gpuTimeBogusValues" */ 'p', 'o', 'w', 'e', 'r', '.', 'g', 'p', 'u', 'T', 'i', 'm', 'e', 'B', 'o', 'g', 'u', 's', 'V', 'a', 'l', 'u', 'e', 's', '\0',
  /*  4962 - "power.wakeupsPerProcessType" */ 'p', 'o', 'w', 'e', 'r', '.', 'w', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', '\0',
  /*  4990 - "power.totalCpuTimeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'C', 'p', 'u', 'T', 'i', 'm', 'e', 'M', 's', '\0',
  /*  5011 - "power.totalGpuTimeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'G', 'p', 'u', 'T', 'i', 'm', 'e', 'M', 's', '\0',
  /*  5032 - "power.totalThreadWakeups" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'T', 'h', 'r', 'e', 'a', 'd', 'W', 'a', 'k', 'e', 'u', 'p', 's', '\0',
  /*  5057 - "powerWakeupsPerThread.parentActive" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5092 - "powerWakeupsPerThread.parentInactive" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5129 - "powerWakeupsPerThread.contentForeground" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  5169 - "powerWakeupsPerThread.contentBackground" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  5209 - "powerWakeupsPerThread.gpuProcess" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'g', 'p', 'u', 'P', 'r', 'o', 'c', 'e', 's', 's', '\0',
  /*  5242 - "powerCpuMsPerThread.parentActive" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5275 - "powerCpuMsPerThread.parentInactive" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5310 - "powerCpuMsPerThread.contentForeground" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  5348 - "powerCpuMsPerThread.contentBackground" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /*  5386 - "powerCpuMsPerThread.gpuProcess" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'g', 'p', 'u', 'P', 'r', 'o', 'c', 'e', 's', 's', '\0',
  /*  5417 - "powerBattery.percentageWhenUserActive" */ 'p', 'o', 'w', 'e', 'r', 'B', 'a', 't', 't', 'e', 'r', 'y', '.', 'p', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'W', 'h', 'e', 'n', 'U', 's', 'e', 'r', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /*  5455 - "searchEngineDefault.engineId" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'e', 'n', 'g', 'i', 'n', 'e', 'I', 'd', '\0',
  /*  5484 - "searchEngineDefault.displayName" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', '\0',
  /*  5516 - "searchEngineDefault.loadPath" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'l', 'o', 'a', 'd', 'P', 'a', 't', 'h', '\0',
  /*  5545 - "searchEngineDefault.submissionUrl" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'r', 'l', '\0',
  /*  5579 - "searchEngineDefault.verified" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\0',
  /*  5608 - "searchEngineDefault.changed" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  5636 - "searchEnginePrivate.engineId" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'e', 'n', 'g', 'i', 'n', 'e', 'I', 'd', '\0',
  /*  5665 - "searchEnginePrivate.displayName" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', '\0',
  /*  5697 - "searchEnginePrivate.loadPath" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'l', 'o', 'a', 'd', 'P', 'a', 't', 'h', '\0',
  /*  5726 - "searchEnginePrivate.submissionUrl" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'r', 'l', '\0',
  /*  5760 - "searchEnginePrivate.verified" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\0',
  /*  5789 - "searchEnginePrivate.changed" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  5817 - "dap.uploadStatus" */ 'd', 'a', 'p', '.', 'u', 'p', 'l', 'o', 'a', 'd', 'S', 't', 'a', 't', 'u', 's', '\0',
  /*  5834 - "dap.reportGenerationStatus" */ 'd', 'a', 'p', '.', 'r', 'e', 'p', 'o', 'r', 't', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'u', 's', '\0',
  /*  5861 - "legacyTelemetry.clientId" */ 'l', 'e', 'g', 'a', 'c', 'y', 'T', 'e', 'l', 'e', 'm', 'e', 't', 'r', 'y', '.', 'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', '\0',
  /*  5886 - "firstStartup.statusCode" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 's', 't', 'a', 't', 'u', 's', 'C', 'o', 'd', 'e', '\0',
  /*  5910 - "firstStartup.elapsed" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', '\0',
  /*  5931 - "update.serviceEnabled" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  5953 - "update.autoDownload" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'a', 'u', 't', 'o', 'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', '\0',
  /*  5973 - "update.backgroundUpdate" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*  5997 - "update.enabled" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  6012 - "update.channel" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'h', 'a', 'n', 'n', 'e', 'l', '\0',
  /*  6027 - "update.canUsuallyApplyUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'A', 'p', 'p', 'l', 'y', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /*  6057 - "update.canUsuallyCheckForUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'C', 'h', 'e', 'c', 'k', 'F', 'o', 'r', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /*  6090 - "update.canUsuallyStageUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'S', 't', 'a', 'g', 'e', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /*  6120 - "update.canUsuallyUseBits" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'U', 's', 'e', 'B', 'i', 't', 's', '\0',
  /*  6145 - "timerThread.timersFiredPerWakeup" */ 't', 'i', 'm', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 't', 'i', 'm', 'e', 'r', 's', 'F', 'i', 'r', 'e', 'd', 'P', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', '\0',
};


static_assert(sizeof(gMetricStringTable) < 4294967296, "Metric string table is too large.");

const metric_entry_t sMetricByNameLookupEntries[] = {
  6917529306813957939ull,
  3458764887482698068ull,
  3458764908957534742ull,
  2882304328452804288ull,
  6917529671886180470ull,
  576460833907802691ull,
  2882303821646660035ull,
  1152922157441880230ull,
  5188147354846367521ull,
  576461100195776638ull,
  5188147595364537534ull,
  8070451039054073224ull,
  10952755174233347678ull,
  2882304173833980595ull,
  6917529349763631101ull,
  4611686211700917315ull,
  4035226116527494540ull,
  3458764956202175442ull,
  6917529345468663779ull,
  576460881152443158ull,
  576461482447868522ull,
  3458764874597796071ull,
  5188147513760158380ull,
  7493990235211041880ull,
  5188147565299766209ull,
  5188147234587282591ull,
  576460756598390784ull,
  1152921556146454930ull,
  3458765424353613590ull,
  1729382295564976421ull,
  8070451077708779094ull,
  5188147599659504868ull,
  7493990230916074546ull,
  3458765132295835642ull,
  1729382269795172431ull,
  2882304680640124737ull,
  6917529328288794522ull,
  1729382750831512911ull,
  6917529603166703340ull,
  10952755148463543721ull,
  10952754993844720072ull,
  2882303782991954066ull,
  4035226198131873660ull,
  2882303851711431263ull,
  8646911855782006485ull,
  4611686722802029017ull,
  2305843026393563256ull,
  6917529504382455028ull,
  8070451137838321577ull,
  5188147539529962283ull,
  1729382299859943758ull,
  576460915512181666ull,
  3458764934727338759ull,
  5188147509465191070ull,
  3458764900367600079ull,
  2882304697819993995ull,
  4611686800111440766ull,
  5764608218818941350ull,
  5188147535234994957ull,
  8646911924501483614ull,
  6917529551627095519ull,
  4035226133707363844ull,
  4035225339138408981ull,
  4611686546708368885ull,
  576461413728391378ull,
  5188146968299308123ull,
  576461478152901198ull,
  6917529332583761838ull,
  4611686203110982666ull,
  2882304676345157419ull,
  5188147664084014777ull,
  6341068524445763105ull,
  2882304186718882607ull,
  2882303877481235158ull,
  3458764689914201049ull,
  576460859677606579ull,
  2882304684935092053ull,
  4611686765751702202ull,
  2882303787286921395ull,
  576461460973031918ull,
  6917529354058598417ull,
  576461289174339118ull,
  5188147569594733540ull,
  5188147591069570203ull,
  9799833626676827433ull,
  6341068533035697784ull,
  4035226138002331169ull,
  576460898332312403ull,
  576460924102116295ull,
  4611686207405949992ull,
  4611686774341636822ull,
  2882303886071169783ull,
  576460902627279725ull,
  4035225815879781995ull,
  8646911804242398668ull,
  6341068515855828420ull,
  5188147350551400194ull,
  5764607733487633595ull,
  7493990368355028801ull,
  2882304165244045922ull,
  5188147586774602874ull,
  6341068498675959059ull,
  6917529341173696466ull,
  6341068545920599809ull,
  576461473857933876ull,
  576461134555515306ull,
  6341068520150795765ull,
  3458764878892763403ull,
  1729382815256022683ull,
  6917529315403892573ull,
  2882303864596333209ull,
  3458764543885312215ull,
  576461224749829343ull,
  2882304702114961321ull,
  6341068494380991732ull,
  576460846792704628ull,
  4611686551003336202ull,
  2882303860301365896ull,
  4035226107937559887ull,
  1729382888270467128ull,
  4035225755750239549ull,
  6917529311108925262ull,
  4611686533823466934ull,
  6341068537330665126ull,
  5188147110033229900ull,
  1152921560441422250ull,
  1152922058657631873ull,
  576461486742835840ull,
  6341068528740730442ull,
  4611686808701375400ull,
  5188147251767151894ull,
  2882304117999405253ull,
  2882303825941627364ull,
  6341068511560861078ull,
  3458764866007861410ull,
  2882304199603784618ull,
  576460838202770001ull,
  7493990389829865410ull,
  5188147578184668209ull,
  2882303941905744879ull,
  5188147238882249918ull,
  4611686559593270853ull,
  10376294228656394604ull,
  6341068541625632471ull,
  9799833540777480901ull,
  4611686641197649937ull,
  2882304706409928650ull,
  5188147603954472202ull,
  8070451133543354261ull,
  6917529336878729152ull,
  5188147530940027631ull,
  2882304139474241920ull,
  576460889742377781ull,
  576460911217214354ull,
  2305843679228596486ull,
  2882304259733327194ull,
  5188147582479635545ull,
  9799833742640945153ull,
  576461418023358701ull,
  2882304208193719299ull,
  2305843571854413486ull,
  4611686804406408083ull,
  2882304710704895976ull,
  4035225343433376299ull,
  576461469562966554ull,
  576461641361659549ull,
  4035225334843441671ull,
  576461409433424062ull,
  4035225901779128394ull,
  1152921513196781611ull,
  9799833437698265230ull,
  2882304375697444834ull,
  6341068502970926401ull,
  8070451034759105896ull,
  2882304272618229147ull,
  4035226112232527212ull,
  4611686791521506121ull,
  5188146976889242786ull,
  576461168915253982ull,
  6917529323993827210ull,
  2882303881776202472ull,
  5188147449335648564ull,
  8070451017579236656ull,
  5188147668378982090ull,
  5188147105738262585ull,
  576460863972573895ull,
  6917529319698859892ull,
  5188147445040681240ull,
  6341068507265893741ull,
  576461027181332261ull,
  5188146972594275454ull,
  3458765196720345430ull,
  3458764913252502075ull,
  9223372633855233915ull,
  3458765420058646270ull,
  3458764548180279545ull,
  2882304388582346790ull,
  2882304221078621311ull,
  3458764921842436742ull,
  576461465267999234ull,
  576460906922247042ull,
  2882304130884307249ull,
  6341068966827397502ull,
  2882304152359143923ull,
  576461615591855592ull,
  3458764943317273430ull,
  4035226142297298497ull,
  4035226125117429195ull,
  4035225313368605046ull,
  5764607737782600910ull,
  576460894037345089ull,
  2882304689230059373ull,
  576460919807148981ull,
  2305843911156831973ull,
  5188147548119896930ull,
  5188147573889700873ull,
  4035226150887233152ull,
  5188147101443295270ull,
  9223372629560266589ull,
  576460885447410472ull,
  5188147114328197220ull,
  3458764947612240767ull
};



static Maybe<uint32_t>
MetricByNameLookup(const nsACString& aKey)
{
  static const uint16_t BASES[] = {
      25,   6,  17,   1,  39,  17,  95,   4,  35,   1,  16,   7,  87,  11,  13,  12,
     249, 127, 107,   1, 122,  14,   1,   2,  70,   6,   8, 154,   2, 131,   9,   4,
       2, 184,  11,   3, 196, 103,  46,   3,  86,  99,  28, 115,  14, 104,  22,  16,
      35,   4, 132, 247,   8,  22, 120,   1, 137,   2,   0, 156,   0,  18, 962,1208,
  };
  

  const char* bytes = aKey.BeginReading();
  size_t length = aKey.Length();
  auto& entry = mozilla::perfecthash::Lookup(bytes, length, BASES,
                                             sMetricByNameLookupEntries);
  return metric_result_check(aKey, entry);
}


/**
 * Get a category's name from the string table.
 */
static const char* GetCategoryName(category_entry_t entry) {
  MOZ_ASSERT(entry < sizeof(gCategoryStringTable), "Entry identifier offset larger than string table");
  return &gCategoryStringTable[entry];
}

/**
 * Get a metric's identifier from the string table.
 */
static const char* GetMetricIdentifier(metric_entry_t entry) {
  uint32_t offset = GLEAN_OFFSET(entry);
  MOZ_ASSERT(offset < sizeof(gMetricStringTable), "Entry identifier offset larger than string table");
  return &gMetricStringTable[offset];
}

/**
 * Check that the found entry is pointing to the right key
 * and return it.
 * Or return `Nothing()` if the entry was not found.
 */
static Maybe<uint32_t> category_result_check(const nsACString& aKey, category_entry_t entry) {
  if (MOZ_UNLIKELY(entry > sizeof(gCategoryStringTable))) {
    return Nothing();
  }
  if (aKey.EqualsASCII(gCategoryStringTable + entry)) {
    return Some(entry);
  }
  return Nothing();
}

/**
 * Check if the found entry index is pointing to the right key
 * and return the corresponding metric ID.
 * Or return `Nothing()` if the entry was not found.
 */
static Maybe<uint32_t> metric_result_check(const nsACString& aKey, uint64_t entry) {
  uint32_t metricId = entry >> GLEAN_INDEX_BITS;
  uint32_t offset = GLEAN_OFFSET(entry);

  if (offset > sizeof(gMetricStringTable)) {
    return Nothing();
  }

  if (aKey.EqualsASCII(gMetricStringTable + offset)) {
    return Some(metricId);
  }

  return Nothing();
}


#undef GLEAN_INDEX_BITS
#undef GLEAN_ID_BITS
#undef GLEAN_TYPE_ID
#undef GLEAN_METRIC_ID
#undef GLEAN_OFFSET

} // namespace mozilla::glean
#endif // mozilla_GleanJSMetricsLookup_h
